from sqlalchemy.orm import validates, relationship
from sqlalchemy import Column, String, Boolean, TIMESTAMP
from .base import Base
import uuid

class Account(Base):
    __tablename__ = 'account'
    
    id = Column(String, primary_key=True, default=lambda: str(uuid.uuid4()))
    name = Column(String, nullable=False)
    cnpj = Column(String(14), unique=True, nullable=False)
    is_active = Column(Boolean, default=True)
    created_at = Column(TIMESTAMP, nullable=False)
    updated_at = Column(TIMESTAMP, nullable=False)

    @validates("cnpj")
    def validate_cnpj(self, key, cnpj):
        if not cnpj.isdigit() or len(cnpj) != 14:
            raise ValueError("CNPJ must be 14 digits long.")
        return cnpj
    
    subscriptions = relationship("Subscription")
    transactions = relationship("Transaction")