from sqlalchemy.orm import Session
from model.user import User

def get_user_by_email(db: Session, email: str):
    return db.query(User).filter(User.email == email).first()

def create_user(db: Session, name: str, email: str, account: str, admin: bool = False):
    new_user = User(name=name, email=email, account=account, is_admin=admin)
    db.add(new_user)
    db.commit()
    db.refresh(new_user)
    return new_user

def get_all_users(db: Session):
    return db.query(User).all()

def get_users_by_account(db: Session, account: str):
    return db.query(User).filter(User.account == account).all()

def soft_delete_user(db: Session, user_id: int):
    user = db.query(User).filter(User.id == user_id).first()
    if user:
        user.is_active = False
        db.commit()
        db.refresh(user)
        return user
    return None

def set_user_as_admin(db: Session, user_id: int):
    user = db.query(User).filter(User.id == user_id).first()
    if user:
        user.is_admin = True
        db.commit()
        db.refresh(user)
        return user
    return None

def set_user_as_normal(db: Session, user_id: int):
    user = db.query(User).filter(User.id == user_id).first()
    if user:
        user.is_admin = False
        db.commit()
        db.refresh(user)
        return user
    return None