from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session
from config.db import SessionLocal
from service.account_service import get_account_by_name, get_account_by_cnpj, create_new_account, list_accounts, patch_account

router = APIRouter(prefix="/accounts", tags=["Accounts"])

def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()

@router.get("/{cnpj}")
def read_account_cnpj(cnpj: str, db: Session = Depends(get_db)):
    account = get_account_by_cnpj(cnpj, db)
    if account:
        return account
    raise HTTPException(status_code=404, detail="Account not found by CNPJ")

@router.get("/{name}")
def read_account_name(name: str, db: Session = Depends(get_db)):
    account = get_account_by_name(name, db)
    if account:
        return account
    raise HTTPException(status_code=404, detail="Account not found by name")

@router.get("/active/{is_active}")
def get_active_accounts(is_active: bool, db: Session = Depends(get_db)):
    return list_accounts(db)

@router.post("/")
def add_account(name: str, cnpj: str, db: Session = Depends(get_db)):
    try:
        return create_new_account(name, cnpj, db)
    except ValueError as e:
        raise HTTPException(status_code=400, detail=str(e))

@router.patch("/update")
def update_account(cnpj: str = None, name: str = None, new_name: str = None, new_cnpj: str = None, db: Session = Depends(get_db)):
    try:
        updated_account = patch_account(db, cnpj, name, new_name, new_cnpj)
        return updated_account
    except HTTPException as e:
        raise e 
    except Exception as e:
        raise HTTPException(status_code=400, detail=str(e))

@router.get("/")
def get_accounts(db: Session = Depends(get_db)):
    return list_accounts(db)


