from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session
from config.db import SessionLocal
from service.user_service import get_user, create_new_user, list_users, list_users_by_account, delete_user, set_user_as_admin, set_user_as_normal

router = APIRouter(prefix="/users", tags=["Users"])

def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()

@router.get("/{email}")
def read_user(email: str, db: Session = Depends(get_db)):
    user = get_user(email, db)
    if user:
        return user
    raise HTTPException(status_code=404, detail="User not found")

@router.post("/")
def add_user(name: str, email: str, account: str, admin: str, db: Session = Depends(get_db)):
    try:
        return create_new_user(name, email, account, admin, db)
    except ValueError as e:
        raise HTTPException(status_code=400, detail=str(e))

@router.get("/")
def get_users(db: Session = Depends(get_db)):
    return list_users(db)

@router.delete("/{email}")
def remove_user(user_id: int, db: Session = Depends(get_db)):
    user = delete_user(user_id, db)
    if user:
        return user
    raise HTTPException(status_code=404, detail="User not found")

@router.put("/{user_id}/admin")
def promote_user_to_admin(user_id: int, db: Session = Depends(get_db)):
    user = set_user_as_admin(user_id, db)
    if user:
        return user
    raise HTTPException(status_code=404, detail="User not found")

@router.put("/{user_id}/normal")
def demote_user_to_normal(user_id: int, db: Session = Depends(get_db)):
    user = set_user_as_normal(user_id, db)
    if user:
        return user
    raise HTTPException(status_code=404, detail="User not found")