from sqlalchemy.orm import Session
from repository import account_repository

def get_account_by_name(name: str, db: Session):
    return account_repository.get_account_by_name(db, name)

def get_account_by_cnpj(cnpj: str, db: Session):
    return account_repository.get_account_by_cnpj(db, cnpj)

def create_new_account(name: str, cnpj: str, db: Session):
    existing_account = account_repository.get_account_by_cnpj(db, cnpj)
    if existing_account:
        raise ValueError("Account with this cnpj already exists.")
    
    return account_repository.create_account(db, name, cnpj)

def list_accounts(db: Session):
    return account_repository.get_all_accounts(db)

def list_active_accounts(db: Session):
    return account_repository.get_account_by_is_active(db)

def patch_account(db: Session, cnpj: str = None, name: str = None, new_name: str = None, new_cnpj: str = None):
    try:
        if not cnpj and not name:
            raise HTTPException(status_code=400, detail="You must provide at least a CNPJ or Name to find the account.")
        account = None

        if name:
            account = account_repository.get_account_by_cnpj(db, cnpj)
        if cnpj:
            account = account_repository.get_account_by_name(db, name)

        if not account:
            raise HTTPException(status_code=404, detail="Account not found.")

        if new_name:
            if account_repository.get_account_by_name(db, new_name) and account.name != new_name:
                raise HTTPException(status_code=405, detail="Name is already in use by another account.")

        if new_cnpj:
            if account_repository.get_account_by_cnpj(db, new_cnpj) and account.cnpj != new_cnpj:
                raise HTTPException(status_code=406, detail="CNPJ is already in use by another account.")

        if new_name:
            account.name = new_name
        if new_cnpj:
            account.cnpj = new_cnpj

        db.commit()
        db.refresh(account)
        return account
    except Exception as e:
        db.rollback()
        raise HTTPException(status_code=400, detail=str(e))
