from sqlalchemy.orm import Session
from repository import user_repository

def get_user(email: str, db: Session):
    return user_repository.get_user_by_email(db, email)

def create_new_user(name: str, email: str, account: str, admin: bool, db: Session):
    existing_user = user_repository.get_user_by_email(db, email)
    if existing_user:
        raise ValueError("User with this email already exists.")
    
    return user_repository.create_user(db, name, email, account, admin)

def list_users(db: Session):
    return user_repository.get_all_users(db)

def list_users_by_account(account: str, db: Session):
    return user_repository.get_users_by_account(db, account)

def delete_user(user_id: int, db: Session):
    return user_repository.soft_delete_user(db, user_id)

def set_user_as_admin(user_id: int, db: Session):
    user = user_repository.get_user_by_email(db, user_id)
    if not user:
        raise ValueError("User not found.")
    
    user_repository.set_user_as_admin(db, user_id)
    
def set_user_as_normal(user_id: int, db: Session):
    user = user_repository.get_user_by_email(db, user_id)
    if not user:
        raise ValueError("User not found.")
    
    user_repository.set_user_as_normal(db, user_id)
    