import pytest
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from repository.account_repository import create_account, get_account_by_cnpj, get_all_accounts
from model.base import Base

# Usando o SQLite em memória -> não persistente
@pytest.fixture(scope='module')
def test_db():
    engine = create_engine('sqlite:///:memory:')
    Base.metadata.create_all(engine)
    TestingSessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)
    db = TestingSessionLocal()
    try:
        yield db
    finally:
        db.close()

def test_create_account(test_db):
    account = create_account(test_db, name="Account Test", cnpj="12345678901234")

    assert account.name == "Account Test"
    assert account.cnpj == "12345678901234"
    
    retrieved_account = get_account_by_cnpj(test_db, cnpj="12345678901234")
    assert retrieved_account is not None
    assert retrieved_account.name == "Account Test"

def test_get_all_accounts(test_db):
    accounts = get_all_accounts(test_db)
    assert len(accounts) > 0
    assert accounts[0].name == "Account Test"
    
    retrieved_accounts = get_all_accounts(test_db)
    assert len(retrieved_accounts) > 0
    assert retrieved_accounts[0].name == "Account Test"